import React from "react";
import { Outlet, useNavigate, Link } from "react-router-dom";

import {
  Toolbar,
  IconButton,
  Avatar,
  Button,
  Typography,
  Container,
  Box,
} from "@mui/material";

import { useWalletConnectContext } from "../context/WalletConnectContext";

const SignPageLayout = () => {
  const { disconnect, session } = useWalletConnectContext();
  const navigate = useNavigate();

  const disconnectHandler = async () => {
    await disconnect();
    navigate("/");
  };

  return (
    <>
      <Toolbar variant="dense">
        <Link to="/" style={{ color: "inherit", textDecoration: "none" }}>
          <Box sx={{ display: "flex", alignItems: "center" }}>
            <Avatar
              alt="Laconic logo"
              src="https://avatars.githubusercontent.com/u/92608123"
            />
            <IconButton
              edge="start"
              color="inherit"
              aria-label="menu"
              sx={{ ml: 2, mr: 2 }}
            >
              Testnet Onboarding
            </IconButton>
          </Box>
        </Link>

        <Button
          variant="outlined"
          style={{
            marginLeft: "auto",
          }}
          color="error"
          onClick={disconnectHandler}
        >
          Disconnect
        </Button>
      </Toolbar>

      <Container maxWidth="md">
        {session && (
          <div style={{ display: "flex", flexDirection: "column" }}>
            <div
              style={{
                display: "flex",
                flexDirection: "row",
                alignItems: "flex-end",
              }}
            >
              <Typography variant="body2">
                Connected to: <b> {session.peer.metadata.name}</b>{" "}
              </Typography>
              <Avatar
                variant="square"
                alt="Peer logo"
                src={session.peer.metadata.icons[0]}
                sx={{
                  width: 20,
                  height: 20,
                  marginLeft: 1,
                  paddingBottom: 0.5,
                }}
              />
            </div>
            <Typography variant="body2">
              Session ID: <b>{session.topic} </b>
            </Typography>
          </div>
        )}
        <Outlet />
      </Container>
    </>
  );
};

export default SignPageLayout;
