import React, { useEffect, useState } from "react";
import { SnackbarProvider, enqueueSnackbar } from "notistack";
import { useParams } from "react-router-dom";

import { Box, Typography } from "@mui/material";
import { Registry } from "@cerc-io/registry-sdk";

interface Participant {
  cosmosAddress: string;
  nitroAddress: string;
}

const registry = new Registry(
  process.env.REACT_APP_REGISTRY_GQL_ENDPOINT!
);

const OnboardingSuccess = () => {
  const { cosmosAddress } = useParams();

  const [participant, setParticipant] = useState<Participant>();

  useEffect(() => {
    const fetchParticipants = async () => {
      try {
        const allParticipants: Participant[] = await registry.getParticipants();
        const participant = allParticipants.find(
          (participant) => participant.cosmosAddress === cosmosAddress
        );

        if (!participant) {
          enqueueSnackbar("Participant not found", { variant: "error" });
          return;
        }

        setParticipant(participant);
      } catch (error) {
        console.error("Error fetching participants", error);
      }
    };

    fetchParticipants();
  }, [cosmosAddress]);

  return (
    <Box
      sx={{
        display: "flex",
        flexDirection: "column",
        marginTop: "100px",
        gap: "10px",
      }}
    >
      <Typography variant="h5">Transaction Successful</Typography>
      <Typography variant="body1">
        Participant onboarded: <br />
      </Typography>
      <Box
        sx={{
          backgroundColor: "lightgray",
          padding: 3,
          wordWrap: "break-word",
        }}
      >
        <pre style={{ whiteSpace: "pre-wrap", margin: 0 }}>
          {participant && (
            <div>
              Cosmos Address: {participant.cosmosAddress} <br />
              Nitro Address: {participant.nitroAddress} <br />
              <br />
            </div>
          )}
        </pre>
      </Box>
      <SnackbarProvider />
    </Box>
  );
};

export default OnboardingSuccess;
